@@ -7,7 +7,7 @@ Attean::API::Query - Utility package defining query-related roles
 
 =head1 VERSION
 
-This document describes Attean::API::Query version 0.015
+This document describes Attean::API::Query version 0.016
 
 =head1 SYNOPSIS
 
@@ -24,7 +24,7 @@ This is a utility package for defining query-related roles:
 
 =cut
 
-package Attean::API::DirectedAcyclicGraph 0.015 {
+package Attean::API::DirectedAcyclicGraph 0.016 {
 	use Moo::Role;
 	use Scalar::Util qw(refaddr);
 	use Types::Standard qw(ArrayRef ConsumerOf);
@@ -149,7 +149,7 @@ package Attean::API::DirectedAcyclicGraph 0.015 {
 	}
 }
 
-package Attean::API::SPARQLSerializable 0.015 {
+package Attean::API::SPARQLSerializable 0.016 {
 	use AtteanX::SPARQL::Constants;
 	use AtteanX::SPARQL::Token;
 	use Moo::Role;
@@ -402,7 +402,7 @@ package Attean::API::SPARQLSerializable 0.015 {
 	}
 }
 
-package Attean::API::SPARQLQuerySerializable 0.015 {
+package Attean::API::SPARQLQuerySerializable 0.016 {
 	use Moo::Role;
 	use namespace::clean;
 	with 'Attean::API::SPARQLSerializable';
@@ -417,7 +417,7 @@ package Attean::API::SPARQLQuerySerializable 0.015 {
 
 =cut
 
-package Attean::API::Algebra 0.015 {
+package Attean::API::Algebra 0.016 {
 	use Moo::Role;
 
 	with 'Attean::API::SPARQLSerializable';
@@ -483,7 +483,7 @@ package Attean::API::Algebra 0.015 {
 				my $children	= $self->children;
 				my $size	= scalar(@$children);
 				unless ($size == $arity) {
-					die "${name} algebra construction with bad number of children (expected $arity, but got $size)";
+					Carp::confess "${name} algebra construction with bad number of children (expected $arity, but got $size)";
 				}
 			}
 		}
@@ -494,7 +494,7 @@ package Attean::API::Algebra 0.015 {
 
 =cut
 
-package Attean::API::QueryTree 0.015 {
+package Attean::API::QueryTree 0.016 {
 	use Moo::Role;
 	with 'Attean::API::DirectedAcyclicGraph';
 }
@@ -503,7 +503,7 @@ package Attean::API::QueryTree 0.015 {
 
 =cut
 
-package Attean::API::NullaryQueryTree 0.015 {
+package Attean::API::NullaryQueryTree 0.016 {
 	use Moo::Role;
 	sub arity { return 0 }
 	with 'Attean::API::QueryTree';
@@ -513,7 +513,7 @@ package Attean::API::NullaryQueryTree 0.015 {
 
 =cut
 
-package Attean::API::UnaryQueryTree 0.015 {
+package Attean::API::UnaryQueryTree 0.016 {
 	use Moo::Role;
 	sub arity { return 1 }
 	with 'Attean::API::QueryTree';
@@ -528,7 +528,7 @@ package Attean::API::UnaryQueryTree 0.015 {
 
 =cut
 
-package Attean::API::BinaryQueryTree 0.015 {
+package Attean::API::BinaryQueryTree 0.016 {
 	use Moo::Role;
 	sub arity { return 2 }
 	with 'Attean::API::QueryTree';
@@ -538,7 +538,7 @@ package Attean::API::BinaryQueryTree 0.015 {
 
 =cut
 
-package Attean::API::PropertyPath 0.015 {
+package Attean::API::PropertyPath 0.016 {
 	use Moo::Role;
 	with 'Attean::API::QueryTree';
 	requires 'as_string';
@@ -549,7 +549,7 @@ package Attean::API::PropertyPath 0.015 {
 
 =cut
 
-package Attean::API::UnaryPropertyPath 0.015 {
+package Attean::API::UnaryPropertyPath 0.016 {
 	use Moo::Role;
 	use Types::Standard qw(ConsumerOf);
 	use namespace::clean;
@@ -579,7 +579,7 @@ package Attean::API::UnaryPropertyPath 0.015 {
 
 =cut
 
-package Attean::API::NaryPropertyPath 0.015 {
+package Attean::API::NaryPropertyPath 0.016 {
 	use Moo::Role;
 	use Types::Standard qw(ArrayRef ConsumerOf);
 	use namespace::clean;
@@ -606,7 +606,7 @@ package Attean::API::NaryPropertyPath 0.015 {
 
 =cut
 
-package Attean::API::UnionScopeVariables 0.015 {
+package Attean::API::UnionScopeVariables 0.016 {
 	use Moo::Role;
 	sub in_scope_variables {
 		my $self	= shift;
@@ -622,7 +622,7 @@ package Attean::API::UnionScopeVariables 0.015 {
 
 =cut
 
-package Attean::API::IntersectionScopeVariables 0.015 {
+package Attean::API::IntersectionScopeVariables 0.016 {
 	use Moo::Role;
 	sub in_scope_variables {
 		my $self	= shift;
