@@ -7,7 +7,7 @@ Attean::QueryPlanner - Query planner
 
 =head1 VERSION
 
-This document describes Attean::QueryPlanner version 0.015
+This document describes Attean::QueryPlanner version 0.016
 
 =head1 SYNOPSIS
 
@@ -23,8 +23,13 @@ This document describes Attean::QueryPlanner version 0.015
 
 =head1 DESCRIPTION
 
-The Attean::QueryPlanner class implements a query planner using the
-iterative dynamic programming approach.
+The Attean::QueryPlanner class is a base class implementing common behavior for
+query planners. Subclasses will need to consume or compose the
+L<Attean::API::JoinPlanner> role.
+
+Trivial sub-classes may consume L<Attean::API::NaiveJoinPlanner>, while more
+complex planners may choose to implement complex join planning (e.g.
+L<Attean::IDPQueryPlanner>).
 
 =head1 ATTRIBUTES
 
@@ -36,7 +41,7 @@ use Attean::Algebra;
 use Attean::Plan;
 use Attean::Expression;
 
-package Attean::QueryPlanner 0.015 {
+package Attean::QueryPlanner 0.016 {
 	use Moo;
 	use Encode qw(encode);
 	use Attean::RDF;
@@ -282,14 +287,19 @@ the supplied C<< $active_graph >>.
 			} else {
 				my $gvar	= $graph->value;
 				my $graphs	= $model->get_graphs;
-				if (my $available = $args{available_graphs}) {
-					$graphs	= Attean::ListIterator->new( item_type => 'Attean::API::Term', values => $available );
-				}
 				my @plans;
 				my %vars		= map { $_ => 1 } $child->in_scope_variables;
 				$vars{ $gvar }++;
 				my @vars	= keys %vars;
 				
+				my %available;
+				if (my $available = $args{available_graphs}) {
+					foreach my $a (@$available) {
+						$available{ $a->value }++;
+					}
+					$graphs	= $graphs->grep(sub { $available{ $_->value } });
+				}
+				
 				my @branches;
 				my %ignore	= map { $_->value => 1 } @$default_graphs;
 				while (my $graph = $graphs->next) {
